#r "System.Windows.Forms"
#r "Microsoft.VisualBasic"

using System.Windows.Forms;
using Microsoft.VisualBasic;
using System.Resources;

string resxPath = Path.Combine(Path.GetDirectoryName(ScriptFilePath), Application.Settings.LanguageCode == "ja" ? "Resources.ja.resx" : "Resources.resx");
ResXResourceSet resx = new ResXResourceSet(resxPath);

var doc = Application.ActiveDocument;

// 選択されている図形を取得する
var selectedShapes = doc.SelectionManager.SelectedShapes;

// 選択数をチェック
if(selectedShapes.Count != 1)
{
    MessageBox.Show(resx.GetString("SelectShapeMessage2"));
    return;
}

// 図形タイプのチェック
if(!(selectedShapes[0].Shape is BasicShape))
{
    MessageBox.Show(resx.GetString("SelectShapeMessage2"));
    return;
}

// 図形タイプのチェック
if(selectedShapes[0].Shape is InfiniteLineShape || selectedShapes[0].Shape is HalfInfiniteLineShape) 
{
    MessageBox.Show(resx.GetString("SelectShapeMessage3"));
    return;
}

// 点列数を入力
string pointNumStr = Interaction.InputBox(resx.GetString("InputNumMessage"), resx.GetString("InputNumMessageTitle"), "10");

int pointNum;
if(string.IsNullOrEmpty(pointNumStr) || !int.TryParse(pointNumStr, out pointNum))
{
	MessageBox.Show(resx.GetString("PointNumMessage"));
    return;
}

// 点列数チェック
if(pointNum < 6 || pointNum > 5000)
{
    MessageBox.Show(resx.GetString("PointNumMessage"));
    return;
}

// 選択した一般図形
var shape = (BasicShape)selectedShapes[0].Shape;

// 図形の長さ
double shapeLength = shape.GetLength(shape.StartParameter, shape.EndParameter);

// 点列の間隔
double resolution = shapeLength / pointNum;
// 点列数を優先させるため間隔を短くする
resolution *= 0.9;

// 一般図形を連続線に変換
var convertPolyline = shape.ConvertToPolyline(resolution, pointNum);

if(convertPolyline == null)
    return;
    
// 連続線の点列を取得
List<Point2d> pointList = new List<Point2d>(convertPolyline.Points);

// テキストデータ作成
string copyText;
foreach(Point2d pt in pointList)
    copyText += pt.ToString() + "\r\n";

// クリップボードにコピー
Clipboard.SetText(copyText);

MessageBox.Show(resx.GetString("CopiedMessage"));

