#r "System.Windows.Forms"

using System.Windows.Forms;
using System.Resources;

string resxPath = Path.Combine(Path.GetDirectoryName(ScriptFilePath), Application.Settings.LanguageCode == "ja" ? "Resources.ja.resx" : "Resources.resx");
ResXResourceSet resx = new ResXResourceSet(resxPath);

var doc = Application.ActiveDocument;

// 選択されている図形を取得する
var selectedShapes = doc.SelectionManager.SelectedShapes;

// 選択数をチェック
if(selectedShapes.Count != 1)
{
    MessageBox.Show(resx.GetString("SelectShapeMessage1"));
    return;
}

// 選択図形
var shape = selectedShapes[0].Shape;

// 図形タイプのチェック
if(!(shape is PolylineShape) && !(shape is LineShape))
{
    MessageBox.Show(resx.GetString("SelectShapeMessage1"));
    return;
}

// 点列のリスト
List<Point2d> pointList;

// 点列データを取得する
if(shape is PolylineShape)
{
	pointList = new List<Point2d>(((PolylineShape)shape).Points);
}
else if(shape is LineShape)
{
	pointList = new List<Point2d>();
	pointList.Add(((LineShape)shape).StartPoint);
	pointList.Add(((LineShape)shape).EndPoint);
}

// テキストデータ作成
string copyText;
foreach(Point2d pt in pointList)
    copyText += pt.ToString() + "\r\n";

// クリップボードにコピー
Clipboard.SetText(copyText);

MessageBox.Show(resx.GetString("CopiedMessage"));

